<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nk="http://netkernel.org"
	xmlns:xrl="http://netkernel.org/xrl">
	<xsl:output method="xml" omit-xml-declaration="yes" />

	<xsl:template match="/panel">
		<div class="template-cp-block">
			
			<xsl:variable name="widget-min">
	     		<xsl:for-each select="widgets/widget/order">
	       			<xsl:sort data-type="number" order="descending"/>
	       			<xsl:if test="position()=1"><xsl:value-of select="."/></xsl:if>
	    		 </xsl:for-each>
	   		</xsl:variable>
			<xsl:variable name="icon-min">
	     		<xsl:for-each select="icons/icon/order">
	       			<xsl:sort data-type="number" order="descending"/>
	       			<xsl:if test="position()=1"><xsl:value-of select="."/></xsl:if>
	    		 </xsl:for-each>
	   		</xsl:variable>
	   		
	   		<xsl:choose>
	   			<xsl:when test="$widget-min &gt; $icon-min">
	   				<xsl:call-template name="icons"/>
	   				<xsl:call-template name="widgets"/>
	   			</xsl:when>
	   			<xsl:otherwise>
	   				<xsl:call-template name="widgets"/>
	   				<xsl:call-template name="icons"/>
	   			</xsl:otherwise>
   			</xsl:choose>			
		</div>
	</xsl:template>
	
	<xsl:template name="widgets">		
		<xsl:if test="widgets/widget">
			<table width="100%">
				<xsl:apply-templates select="widgets/widget" />
			</table>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="icons">
		<xsl:variable name="count" select="count(icons/icon)"/>
		<xsl:if test="$count">
			<xsl:variable name="half" select="round($count div 2)"/>
			<table cellspacing="0" cellpadding="0" width="800">
				<xsl:for-each select="icons/icon[(position() &lt;= $half) ]">
					<xsl:variable name="pos" select="position()" />
					<tr>
						<xsl:apply-templates select="." />
						<xsl:apply-templates select="../icon[$pos+$half]" />
					</tr>					
				</xsl:for-each>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template match="icon">
		<td class="template-icon-block" width="50%">
			<a href="{path}" class="template-lbi">
				<div style="display: table-row;">
					<div style="float: left; display:table-cell; vertical-align:middle;">
						<img border="0" width="48" height="48" style="margin-right: 4px; margin-left: 2px;">
						<xsl:choose>
							<xsl:when test="icon">
								<xsl:attribute name="src"><xsl:value-of select="icon"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="src">/nkse/style/img/noicon.png</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						</img>
					</div>
					<div style="display:table-cell; vertical-align:middle;" >
						<p class="template-icon-title">
							<xsl:value-of select="title" />
						</p>
						<p class="template-icon-subtitle">
							<xsl:value-of select="subtitle" />
						</p>
					</div>
				</div>
				 
			</a>
		</td>
		<!-- 
		<td class="template-icon-block">
			<a href="{path}">
				<xsl:choose>
					<xsl:when test="icon">
						<img src="{icon}" border="0" />
					</xsl:when>
					<xsl:otherwise>
						<img src="/nkse/style/img/noicon.png" border="0" />
					</xsl:otherwise>
				</xsl:choose>
			</a>
		</td>
		<td>
			<div class="template-icon-title">
				<a href="{path}">
					<xsl:value-of select="title" />
				</a>
			</div>
			<div class="template-icon-subtitle">
				<xsl:value-of select="subtitle" />
			</div>
		</td>
		 -->
	</xsl:template>

	<xsl:template match="widget">
		<tr>
			<td>
				<xsl:choose>
					<xsl:when test="request">
						<xrl:include>
							<xrl:identifier>
								<xsl:value-of select="request/identifier" />
							</xrl:identifier>
							<xsl:for-each select="request/argument">
								<xrl:argument>
									<xsl:attribute name="name"><xsl:value-of
										select="@name" /></xsl:attribute>
									<xsl:choose>
										<xsl:when test="*">
											<xsl:copy-of select="*" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="." />
										</xsl:otherwise>
									</xsl:choose>
								</xrl:argument>
							</xsl:for-each>
						</xrl:include>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="div" />
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
	</xsl:template>


</xsl:stylesheet>
